@@ -31,6 +31,9 @@
 #include "PlatformBackends/ImageGrabber.h"
 #include "ExportMenu.h"
 #include "KSWidget.h"
+#include "SpectacleConfig.h"
+
+class KMoreToolsMenuFactory;
 
 class KSMainWindow : public QDialog
 {
@@ -45,14 +48,15 @@ class KSMainWindow : public QDialog
 
     void captureScreenshot(ImageGrabber::GrabMode mode, int timeout, bool includePointer, bool includeDecorations);
     void showPrintDialog();
+    void openScreenshotsFolder();
     void showPreferencesDialog();
     void showImageSharedFeedback(bool error, const QString &message);
     void sendToClipboard();
     void init();
-    void buildSaveMenu();
+    void setDefaultSaveAction();
     void save();
     void saveAs();
-    void saveAndExit();
+    int windowWidth(const QPixmap &pixmap) const;
 
     public slots:
 
@@ -73,11 +77,18 @@ class KSMainWindow : public QDialog
     KSWidget         *mKSWidget;
     QFrame           *mDivider;
     QDialogButtonBox *mDialogButtonBox;
+    QToolButton      *mConfigureButton;
+    QPushButton      *mToolsButton;
     QPushButton      *mSendToButton;
     QToolButton      *mClipboardButton;
     QToolButton      *mSaveButton;
     QMenu            *mSaveMenu;
+    QAction          *mSaveAsAction;
+    QAction          *mSaveAction;
     KMessageWidget   *mMessageWidget;
+    QMenu            *mToolsMenu;
+    QMenu            *mScreenRecorderToolsMenu;
+    QScopedPointer<KMoreToolsMenuFactory> mScreenrecorderToolsMenuFactory;
     ExportMenu       *mExportMenu;
     bool              mOnClickAvailable;
 };
