@@ -19,31 +19,29 @@
 
 #include "SaveOptionsPage.h"
 
+#include "SpectacleConfig.h"
+
+#include <KIOWidgets/KUrlRequester>
+#include <KLocalizedString>
+
 #include <QLineEdit>
 #include <QLabel>
 #include <QGroupBox>
 #include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QStandardPaths>
 #include <QComboBox>
 #include <QImageWriter>
 
-#include <KLocalizedString>
-#include <KIOWidgets/KUrlRequester>
-
-#include "SpectacleConfig.h"
-
 SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     SettingsPage(parent)
 {
     // set up the layout. start with the directory
 
-    QGroupBox *dirGroup = new QGroupBox(i18n("Default Save Location"));
+    QGroupBox *dirGroup = new QGroupBox(i18n("Default Save Location"), this);
     QVBoxLayout *dirLayout = new QVBoxLayout;
     dirGroup->setLayout(dirLayout);
 
     QHBoxLayout *urlRequesterLayout = new QHBoxLayout;
-    urlRequesterLayout->addWidget(new QLabel(i18n("Location:")));
+    urlRequesterLayout->addWidget(new QLabel(i18n("Location:"), this));
 
     mUrlRequester = new KUrlRequester;
     mUrlRequester->setMode(KFile::Directory);
@@ -59,7 +57,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     fmtGroup->setLayout(fmtLayout);
 
     QHBoxLayout *saveNameLayout = new QHBoxLayout;
-    saveNameLayout->addWidget(new QLabel(i18n("Filename:")));
+    saveNameLayout->addWidget(new QLabel(i18n("Filename:"), this));
 
     mSaveNameFormat = new QLineEdit;
     connect(mSaveNameFormat, &QLineEdit::textEdited, this, &SaveOptionsPage::markDirty);
@@ -67,7 +65,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
         QString fmt;
         Q_FOREACH(auto item, QImageWriter::supportedImageFormats()) {
             fmt = QString::fromLocal8Bit(item);
-            if (newText.endsWith(QStringLiteral(".") + fmt, Qt::CaseInsensitive)) {
+            if (newText.endsWith(QLatin1Char('.') + fmt, Qt::CaseInsensitive)) {
                 QString txtCopy = newText;
                 txtCopy.chop(fmt.length() + 1);
                 mSaveNameFormat->setText(txtCopy);
@@ -103,14 +101,15 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
             "<b>%D</b>: Day<br />"
             "<b>%H</b>: Hour<br />"
             "<b>%m</b>: Minute<br />"
-            "<b>%S</b>: Second"
+            "<b>%S</b>: Second<br />"
+            "<b>%T</b>: Window title"
         "</blockquote>"
     );
 
-    QLabel *fmtHelpText = new QLabel;
+    QLabel *fmtHelpText = new QLabel(helpText, this);
     fmtHelpText->setWordWrap(true);
-    fmtHelpText->setText(helpText);
     fmtHelpText->setTextFormat(Qt::RichText);
+    fmtHelpText->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     fmtLayout->addWidget(fmtHelpText);
 
     // read in the data
