@@ -18,22 +18,6 @@
  */
 
 #include "SpectacleCore.h"
-#include "SpectacleConfig.h"
-
-#include <QClipboard>
-#include <QDir>
-#include <QTimer>
-#include <QDebug>
-#include <QMimeData>
-#include <QDrag>
-
-#include <KMessageBox>
-#include <KNotification>
-#include <KWindowSystem>
-#include <KLocalizedString>
-#include <KRun>
-#include <KConfigGroup>
-#include <KSharedConfig>
 
 #include "Config.h"
 #include "PlatformBackends/DummyImageGrabber.h"
@@ -42,6 +26,19 @@
 #endif
 #include "PlatformBackends/KWinWaylandImageGrabber.h"
 
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KNotification>
+#include <KRun>
+#include <KWindowSystem>
+
+#include <QClipboard>
+#include <QDebug>
+#include <QDir>
+#include <QDrag>
+#include <QMimeData>
+#include <QTimer>
+
 SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMode, QString &saveFileName,
                qint64 delayMsec, bool notifyOnGrab, QObject *parent) :
     QObject(parent),
@@ -62,20 +59,23 @@ SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMod
         setFilename(saveFileName);
     }
 
+    // We might be using the XCB platform (with Xwayland) in a wayland session,
+    // but the X11 grabber won't work in that case. So force the Wayland grabber
+    // in Wayland sessions.
+    if (KWindowSystem::isPlatformWayland() || qstrcmp(qgetenv("XDG_SESSION_TYPE"), "wayland") == 0) {
+        mImageGrabber = new KWinWaylandImageGrabber;
+    }
 #ifdef XCB_FOUND
-    if (KWindowSystem::isPlatformX11()) {
+    if (!mImageGrabber && KWindowSystem::isPlatformX11()) {
         mImageGrabber = new X11ImageGrabber;
     }
 #endif
-    if (!mImageGrabber && KWindowSystem::isPlatformWayland()) {
-        mImageGrabber = new KWinWaylandImageGrabber;
-    }
 
     if (!mImageGrabber) {
         mImageGrabber = new DummyImageGrabber;
     }
 
-    mImageGrabber->setGrabMode(grabMode);
+    setGrabMode(grabMode);
     mImageGrabber->setCapturePointer(guiConfig.readEntry("includePointer", true));
     mImageGrabber->setCaptureDecorations(guiConfig.readEntry("includeDecorations", true));
 
@@ -86,6 +86,7 @@ SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMod
     connect(mExportManager, &ExportManager::errorMessage, this, &SpectacleCore::showErrorMessage);
     connect(this, &SpectacleCore::errorMessage, this, &SpectacleCore::showErrorMessage);
     connect(mImageGrabber, &ImageGrabber::pixmapChanged, this, &SpectacleCore::screenshotUpdated);
+    connect(mImageGrabber, &ImageGrabber::windowTitleChanged, mExportManager, &ExportManager::setWindowTitle);
     connect(mImageGrabber, &ImageGrabber::imageGrabFailed, this, &SpectacleCore::screenshotFailed);
     connect(mExportManager, &ExportManager::imageSaved, this, &SpectacleCore::doCopyPath);
     connect(mExportManager, &ExportManager::forceNotify, this, &SpectacleCore::doNotify);
@@ -132,6 +133,7 @@ ImageGrabber::GrabMode SpectacleCore::grabMode() const
 void SpectacleCore::setGrabMode(const ImageGrabber::GrabMode &grabMode)
 {
     mImageGrabber->setGrabMode(grabMode);
+    mExportManager->setGrabMode(grabMode);
 }
 
 // Slots
@@ -148,7 +150,7 @@ void SpectacleCore::dbusStartAgent()
 void SpectacleCore::takeNewScreenshot(const ImageGrabber::GrabMode &mode,
                                const int &timeout, const bool &includePointer, const bool &includeDecorations)
 {
-    mImageGrabber->setGrabMode(mode);
+    setGrabMode(mode);
     mImageGrabber->setCapturePointer(includePointer);
     mImageGrabber->setCaptureDecorations(includeDecorations);
 
@@ -209,6 +211,8 @@ void SpectacleCore::screenshotFailed()
     switch (mStartMode) {
     case BackgroundMode:
         showErrorMessage(i18n("Screenshot capture canceled or failed"));
+        emit allDone();
+        return;
     case DBusMode:
         emit grabFailed();
         emit allDone();
@@ -279,7 +283,6 @@ void SpectacleCore::doStartDragAndDrop()
 
     QMimeData *mimeData = new QMimeData;
     mimeData->setUrls(QList<QUrl> { tempFile });
-    mimeData->setImageData(mExportManager->pixmap());
     mimeData->setData(QStringLiteral("application/x-kde-suggestedfilename"), QFile::encodeName(tempFile.fileName()));
 
     QDrag *dragHandler = new QDrag(this);
